@@ -1,3 +1,4 @@
+/* vim: set et ts=2 sts=2 sw=2 : */
 /************************************************************************************\
 *                                                                                    *
 * Copyright (c) 2014, Dr. Eugene W. Myers (EWM). All rights reserved.                *
@@ -54,18 +55,13 @@
  *  Last Mod:  July 2015
  *
  *******************************************************************************************/
+#include "DB.h"
+#include "DBX.h"
+#include "align.h"
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdint.h>
-#include <ctype.h>
-#include <unistd.h>
-#include <stdbool.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#include "DB.h"
-#include "align.h"
 
 #define MAX_OVERLAPS 50000
 
@@ -144,12 +140,13 @@ static bool add_overlap(const Alignment *aln, const Overlap *ovl, const int coun
     return added;
 }
 
-static void print_hits(const int hit_count, HITS_DB *db2, char *bbuffer, char buffer[], int64 bsize, const int MAX_HIT_COUNT) {
+static void print_hits(const int hit_count, HITS_DBX *dbx2, char *bbuffer, char buffer[], int64 bsize, const int MAX_HIT_COUNT) {
     int tmp_idx;
     qsort(ovlgrps, (hit_count+1), sizeof(OverlapGroup), compare_ovlgrps);
     for (tmp_idx = 0; tmp_idx < (hit_count+1) && tmp_idx < MAX_HIT_COUNT; tmp_idx++) {
         OverlapGroup *grp = &ovlgrps[tmp_idx];
-        Load_Read(db2, grp->end.bread, bbuffer, 0);
+        //Load_ReadX assuming db2 == db1 is true
+        Load_ReadX(dbx2, grp->end.bread, bbuffer, 0);
         if (COMP(grp->end.flags)) Complement_Seq(bbuffer, grp->blen );
         Upper_Read(bbuffer);
         int64 const rlen = (int64)(grp->end.path.bepos) - (int64)(grp->beg.path.bbpos);
@@ -178,8 +175,10 @@ static int ORDER(const void *l, const void *r)
 }
 
 int main(int argc, char *argv[])
-{ HITS_DB   _db1, *db1 = &_db1;
-  HITS_DB   _db2, *db2 = &_db2;
+{ HITS_DBX   _dbx1, *dbx1 = &_dbx1;
+  HITS_DBX   _dbx2, *dbx2 = &_dbx2;
+  HITS_DB *db1 = &dbx1->db;
+  HITS_DB *db2 = &dbx2->db;
   Overlap   _ovl, *ovl = &_ovl;
   Alignment _aln, *aln = &_aln;
 
@@ -196,6 +195,7 @@ int main(int argc, char *argv[])
   int     FALCON, OVERLAP, M4OVL;
   // XXX: MAX_HIT_COUNT should be renamed
   int     SEED_MIN, MAX_HIT_COUNT, SKIP;
+  int     PRELOAD;
 
   //  Process options
 
@@ -225,7 +225,7 @@ int main(int argc, char *argv[])
       if (argv[i][0] == '-')
         switch (argv[i][1])
         { default:
-            ARG_FLAGS("smfocargUFM")
+            ARG_FLAGS("smfocargUFMP")
             break;
           case 'i':
             ARG_NON_NEGATIVE(INDENT,"Indent")
@@ -259,6 +259,7 @@ int main(int argc, char *argv[])
     FALCON    = flags['f'];
     SKIP      = flags['s'];
     GROUP     = flags['g'];
+    PRELOAD   = flags['P']; // Preload DB reads, if possible.
 
     if (argc <= 2)
       { fprintf(stderr,"Usage: %s %s\n",Prog_Name,Usage[0]);
@@ -274,7 +275,7 @@ int main(int argc, char *argv[])
     FILE *input;
 
     ISTWO  = 0;
-    status = Open_DB(argv[1],db1);
+    status = Open_DBX(argv[1],dbx1,PRELOAD);
     if (status < 0)
       exit (1);
     if (db1->part > 0)
@@ -288,7 +289,7 @@ int main(int argc, char *argv[])
         if ((input = fopen(Catenate(pwd,"/",root,".las"),"r")) != NULL)
           { ISTWO = 1;
             fclose(input);
-            status = Open_DB(argv[2],db2);
+            status = Open_DBX(argv[2],dbx2,PRELOAD);
             if (status < 0)
               exit (1);
             if (db2->part > 0)
@@ -298,12 +299,16 @@ int main(int argc, char *argv[])
             Trim_DB(db2);
           }
         else
-          db2 = db1;
+            { dbx2 = dbx1;
+              db2 = db1;
+            }
         free(root);
         free(pwd);
       }
     else
-      db2 = db1;
+      { dbx2 = dbx1;
+        db2 = db1;
+      }
     Trim_DB(db1);
   }
 
@@ -697,16 +702,16 @@ int main(int argc, char *argv[])
         if (FALCON)
           {
             if (p_aread == -1) {
-                Load_Read(db1, ovl->aread, abuffer, 2);
+                Load_ReadX(dbx1, ovl->aread, abuffer, 2);
                 printf("%08d %s\n", ovl->aread, abuffer);
                 p_aread = ovl->aread;
                 skip_rest = 0;
             }
             if (p_aread != ovl -> aread ) {
-                print_hits(hit_count, db2, bbuffer, buffer, (int64)sizeof(buffer), MAX_HIT_COUNT);
+                print_hits(hit_count, dbx2, bbuffer, buffer, (int64)sizeof(buffer), MAX_HIT_COUNT);
                 hit_count = -1;
 
-                Load_Read(db1, ovl->aread, abuffer, 2);
+                Load_ReadX(dbx1, ovl->aread, abuffer, 2);
                 printf("%08d %s\n", ovl->aread, abuffer);
                 p_aread = ovl->aread;
                 skip_rest = 0;
@@ -725,8 +730,8 @@ int main(int argc, char *argv[])
                     tps = ((ovl->path.aepos-1)/tspace - ovl->path.abpos/tspace);
                     if (small)
                         Decompress_TraceTo16(ovl);
-                    Load_Read(db1, ovl->aread, abuffer, 0);
-                    Load_Read(db2, ovl->bread, bbuffer, 0);
+                    Load_ReadX(dbx1, ovl->aread, abuffer, 0);
+                    Load_ReadX(dbx2, ovl->bread, bbuffer, 0);
                     if (COMP(aln->flags))
                         Complement_Seq(bbuffer, aln->blen);
                     Compute_Trace_PTS(aln,work,tspace);
@@ -828,7 +833,7 @@ int main(int argc, char *argv[])
 
     if (FALCON && hit_count != -1)
       {
-        print_hits(hit_count, db2, bbuffer, buffer, (int64)sizeof(buffer), MAX_HIT_COUNT);
+        print_hits(hit_count, dbx2, bbuffer, buffer, (int64)sizeof(buffer), MAX_HIT_COUNT);
         printf("- -\n");
         free(ovlgrps);
       }
@@ -842,9 +847,8 @@ int main(int argc, char *argv[])
       }
   }
 
-  Close_DB(db1);
+  Close_DBX(dbx1);
   if (ISTWO)
-    Close_DB(db2);
-
+    Close_DBX(dbx2);
   exit (0);
 }
