@@ -194,6 +194,7 @@ def script_build_rdb(config, input_fofn_fn, run_jobs_bfn):
         mdust = ''
     params.update(locals())
     script = """\
+echo "PBFALCON_ERRFILE=$PBFALCON_ERRFILE"
 set -o pipefail
 #fc_fasta2fasta < {input_fofn_fn} >| fc.fofn
 while read fn; do  {cat_fasta} $fn | fasta2DB -v raw_reads -i${{fn##*/}}; done < {input_fofn_fn}
@@ -307,8 +308,9 @@ rmfollow() {
             if not line.startswith('LAmerge'):
                 continue
             las_files = [word + '.las' for word in functional.yield_args_from_line(line)]
-            assert las_fn == os.path.basename(las_files[0])
-            script.extend('rmfollow {}'.format(fn) for fn in las_files[1:])
+            #las_fn = os.path.basename(las_files[0])
+            #assert las_fn == os.path.basename(las_files[0])
+            script.extend('# rmfollow {}'.format(fn) for fn in las_files[1:])
             break
 
         content = bash_funcs + '\n'.join(script + [''])
@@ -327,13 +329,16 @@ def script_run_consensus(config, db_fn, las_fn, out_file_bfn):
     else:
         bash_cutoff = '{}'.format(length_cutoff)
     params.update(locals())
+    LA4Falcon_flags = 'P' if params.get('LA4Falcon_preload') else ''
     if config["falcon_sense_skip_contained"]:
-        run_consensus = """LA4Falcon -H$CUTOFF -fso {db_fn} {las_fn} | """
+        LA4Falcon_flags += 'fso'
     elif config["falcon_sense_greedy"]:
-        run_consensus = """LA4Falcon -H$CUTOFF -fog  {db_fn} {las_fn} | """
+        LA4Falcon_flags += 'fog'
     else:
-        run_consensus = """LA4Falcon -H$CUTOFF -fo  {db_fn} {las_fn} | """
-    run_consensus += """fc_consensus {falcon_sense_option} >| {out_file_bfn}"""
+        LA4Falcon_flags += 'fo'
+    if LA4Falcon_flags:
+        LA4Falcon_flags = '-' + ''.join(set(LA4Falcon_flags))
+    run_consensus = "LA4Falcon -H$CUTOFF %s {db_fn} {las_fn} | fc_consensus {falcon_sense_option} >| {out_file_bfn}"%LA4Falcon_flags
 
     if config.get('dazcon', False):
         run_consensus = """
@@ -378,6 +383,6 @@ def script_run_report_pre_assembly(i_raw_reads_db_fn, i_preads_fofn_fn, genome_l
     params = dict()
     params.update(locals())
     script = """\
-python -m falcon_kit.mains.report_pre_assembly --genome-length {genome_length} --length-cutoff {length_cutoff} --db {i_raw_reads_db_fn} --preads-fofn {i_preads_fofn_fn} --out {o_json_fn}
+python2.7 -m falcon_kit.mains.report_pre_assembly --genome-length {genome_length} --length-cutoff {length_cutoff} --db {i_raw_reads_db_fn} --preads-fofn {i_preads_fofn_fn} --out {o_json_fn}
 """
     return script.format(**params)
