@@ -1,6 +1,7 @@
 from .. import run_support as support
 from .. import bash, pype_tasks
-from ..util.system import only_these_symlinks
+from ..util.system import (only_these_symlinks, lfs_setstripe_maybe)
+# pylint: disable=no-name-in-module, import-error, fixme, line-too-long
 from pypeflow.simple_pwatcher_bridge import (PypeProcWatcherWorkflow, MyFakePypeThreadTaskBase,
         makePypeLocalFile, fn, PypeTask)
 import argparse
@@ -13,7 +14,7 @@ import sys
 import time
 
 
-fc_run_logger = logging.getLogger(__name__) # default, for remote tasks
+LOG = logging.getLogger(__name__) # default, for remote tasks
 
 
 def create_daligner_tasks(basedir, scatter_fn):
@@ -111,14 +112,14 @@ def create_consensus_gather_task(wd, inputs):
 
 
 def main1(prog_name, input_config_fn, logger_config_fn=None):
-    global fc_run_logger
-    fc_run_logger = support.setup_logger(logger_config_fn)
+    global LOG
+    LOG = support.setup_logger(logger_config_fn)
 
-    fc_run_logger.info('fc_run started with configuration %s', input_config_fn)
+    LOG.info('fc_run started with configuration %s', input_config_fn)
     try:
         config = support.get_dict_from_old_falcon_cfg(support.parse_config(input_config_fn))
     except Exception:
-        fc_run_logger.exception('Failed to parse config "{}".'.format(input_config_fn))
+        LOG.exception('Failed to parse config "{}".'.format(input_config_fn))
         raise
     input_fofn_plf = makePypeLocalFile(config['input_fofn'])
     genome_size = config.get('genome_size')
@@ -143,7 +144,7 @@ def run(wf, config,
         ):
     """
     Preconditions (for now):
-    * fc_run_logger
+    * LOG
     * run_support.logger
     """
     rawread_dir = os.path.abspath('./0-rawreads')
@@ -156,20 +157,21 @@ def run(wf, config,
         support.make_dirs(d)
 
     exitOnFailure=config['stop_all_jobs_on_failure'] # only matter for parallel jobs
-    concurrent_jobs = config['pa_concurrent_jobs']
-    wf.max_jobs = concurrent_jobs
+    wf.max_jobs = config['default_concurrent_jobs']
 
-    rawread_fofn_plf = makePypeLocalFile(os.path.join(rawread_dir, 'raw-fofn-abs', os.path.basename(config['input_fofn'])))
-    make_fofn_abs_task = PypeTask(inputs = {'i_fofn': input_fofn_plf},
-                                  outputs = {'o_fofn': rawread_fofn_plf},
-                                  parameters = {},
-    )
-    fofn_abs_task = make_fofn_abs_task(pype_tasks.task_make_fofn_abs_raw)
-
-    wf.addTasks([fofn_abs_task])
-    wf.refreshTargets([fofn_abs_task])
+    assert config['input_type'] in ('raw', 'preads'), 'Invalid input_type=={!r}'.format(config['input_type'])
 
     if config['input_type'] == 'raw':
+        rawread_fofn_plf = makePypeLocalFile(os.path.join(rawread_dir, 'raw-fofn-abs', os.path.basename(config['input_fofn'])))
+        make_fofn_abs_task = PypeTask(inputs = {'i_fofn': input_fofn_plf},
+                                    outputs = {'o_fofn': rawread_fofn_plf},
+                                    parameters = {},
+        )
+        fofn_abs_task = make_fofn_abs_task(pype_tasks.task_make_fofn_abs_raw)
+
+        wf.addTasks([fofn_abs_task])
+        wf.refreshTargets([fofn_abs_task])
+
         #### import sequences into daligner DB
         sleep_done = makePypeLocalFile( os.path.join( rawread_dir, 'sleep_done') )
         rdb_build_done = makePypeLocalFile( os.path.join( rawread_dir, 'rdb_build_done') )
@@ -196,6 +198,7 @@ def run(wf, config,
 
         raw_reads_nblock = support.get_nblock(fn(raw_reads_db_plf))
         #### run daligner
+        wf.max_jobs = config['da_concurrent_jobs']
         scattered_plf = os.path.join(rawread_dir, 'daligner-scatter', 'scattered.json')
         make_daligner_scatter = PypeTask(
                 inputs = {
@@ -234,6 +237,7 @@ def run(wf, config,
         wf.refreshTargets(exitOnFailure=exitOnFailure)
 
         # Merge .las files.
+        wf.max_jobs = config['la_concurrent_jobs']
         scattered_plf = os.path.join(rawread_dir, 'merge-scatter', 'scattered.json')
         make_task = PypeTask(
                 inputs = {
@@ -262,8 +266,7 @@ def run(wf, config,
             sys.exit(0)
 
         # Produce new FOFN of preads fasta, based on consensus of overlaps.
-        concurrent_jobs = config['cns_concurrent_jobs']
-        wf.max_jobs = concurrent_jobs
+        wf.max_jobs = config['cns_concurrent_jobs']
 
         scattered_plf = os.path.join(rawread_dir, 'cns-scatter', 'scattered.json')
         make_task = PypeTask(
@@ -308,13 +311,13 @@ def run(wf, config,
 
 
     if config['target'] == 'pre-assembly':
-        log.info('Quitting after stage-0 for "pre-assembly" target.')
+        LOG.info('Quitting after stage-0 for "pre-assembly" target.')
         sys.exit(0)
 
     # build pread database
     if config['input_type'] == 'preads':
         preads_fofn_plf = makePypeLocalFile(os.path.join(pread_dir, 'preads-fofn-abs', os.path.basename(config['input_fofn'])))
-        make_fofn_abs_task = PypeTask(inputs = {'i_fofn': rawread_fofn_plf},
+        make_fofn_abs_task = PypeTask(inputs = {'i_fofn': input_fofn_plf},
                                      outputs = {'o_fofn': preads_fofn_plf},
                                      parameters = {},
         )
@@ -345,9 +348,7 @@ def run(wf, config,
 
     preads_nblock = support.get_nblock(fn(preads_db))
     #### run daligner
-    concurrent_jobs = config['ovlp_concurrent_jobs']
-    wf.max_jobs = concurrent_jobs
-
+    wf.max_jobs = config['pda_concurrent_jobs']
     config['sge_option_da'] = config['sge_option_pda']
 
     scattered_plf = os.path.join(pread_dir, 'daligner-scatter', 'scattered.json')
@@ -387,6 +388,7 @@ def run(wf, config,
     wf.refreshTargets(exitOnFailure=exitOnFailure)
 
     # Merge .las files.
+    wf.max_jobs = config['pla_concurrent_jobs']
     config['sge_option_la'] = config['sge_option_pla']
     scattered_plf = os.path.join(pread_dir, 'merge-scatter', 'scattered.json')
     make_task = PypeTask(
@@ -414,6 +416,8 @@ def run(wf, config,
     wf.refreshTargets(exitOnFailure=exitOnFailure)
 
 
+    # Draft assembly (called 'fc_' for now)
+    wf.max_jobs = config['fc_concurrent_jobs']
     db2falcon_dir = os.path.join(pread_dir, 'db2falcon')
     db2falcon_done = makePypeLocalFile(os.path.join(db2falcon_dir, 'db2falcon_done'))
     preads4falcon_plf = makePypeLocalFile(os.path.join(db2falcon_dir, 'preads4falcon.fasta'))
@@ -451,6 +455,7 @@ def run(wf, config,
 
 
 def main(argv=sys.argv):
+    lfs_setstripe_maybe(path='.', stripe=12)
     parser = argparse.ArgumentParser()
     parser.add_argument('config',
         help='.cfg/.ini/.json')
